//+------------------------------------------------------------------+
//|                                         MetaNeural SuperDash.mq4 |
//|                                                        FalseDave |
//|                                 http://www.SteveHopwoodForex.com |
//+------------------------------------------------------------------+

/*
   Meta Neural SuperDash 
   
   Based on the MetaNeural Dashboard.mQ4 & MetaNeural_VSA_SR.
   
   Version Beta1 (10/03/2013)
   
   Notes.
   
   SuperDash can be back tested. One pair at a time. Although very slowly , I admit this is probably due to the inefficiency of my
   code. Once Superdash is up and running correctly we can look at ways to optimize and speed this up.
   
   VSA_SR indicator and the Dashboard EA have been combined together and allowed it to look at all possible pairs.
   
   Re-wrote FindTP to store Support and Resistance Levels in an Array rather than looking at objects.
   
   LotSizes - MM Needs some work as it does not give a predifined risk reward ratio. So an order may risk 1% of equity if hits SL 
   but may TP for less than this amount.
   
   Partial Close. - Works O.K but perhaps needs some work.
   
   Orders are closed before SL but only when they are in profit. This may not be to our benefit. Cut losers early and all that.

   The Original MetaNeural Dashboard had a re-entry feature. I didnt like it so I took it out. Might add it as an option later.
   Superdash currently uses the next S/R line as SL if this is closer than 150 points it make ths SL 150 points away. I think this
   minimum SL could be linked to something like the average daily range to create a more dynamic EA.
   
   At the moment. Superdash only allows for one trade per trading session. This might be a benefit to prevent overtrading.
   Or it may be limiting potential profit.
   If a STOP/LIMIT order is deleted before it is executed. Should that symbol be allowed to trade again in that session ?
   
   If you do edit this EA please feel free to edit the notes to show what you have fixed/improved.
   
   Credit to MetaNeural for the use of the Dashboard and Indicator.  
*/
#property copyright "Copyright 2013, MetaQuotes Software Corp."
#property link      "http://www.SteveHopwoodForex.com"

#define NONE 0
#define UP 1
#define DOWN 2

#define STRENGTH 5
#define FAILURE 6

int BarsBack = 100;                                               // Used by VSA_SR - How many bars to look back to calcualate support/resistance lines.

extern color                  TextColor = White;                  // Color of the Text used in the indicator. 
extern int                     TextSize = 9;                      // Size of the Text used.

extern bool                TradeEnabled = true;                   // Bool to select either to actively trade of to just use as an indicator.
extern int                        MAGIC = 9873298;                // Magic Number
extern string              TradeComment = " SuperDash v1 ";       // Comment to identify trades.
extern double                   LotSize = 0.01;                   // Fixed lot size if risk = 0                
extern double                      Risk = 0.01;                      // Amount to Risk as a percentage of Total Equity. 
extern int        PartialTakePercentage = 50;                     // Amount in percent to take when using a partial close;

extern int          Asian_Session_Start = 2;                      // Start time of the Asian session in server time
extern int           Euro_Session_Start = 8;                      // Start time of the European Session in server time
extern int             US_Session_Start = 15;                     // Start time of the American Session in server time

string Suffix;                                                    // Suffix used by the broker
int PairCount;                                                    // Variable for number of pairs monitored and traded.
string aPair[];                                                   // Array that holds all the pair names.

double dc[],dc2[],do[],do2[],dh[],dh2[],dl[],dl2[],dr[],dv[],dv2[];        // These Arrays hold all DAILY price information for each Symbol   
double hc[],hc2[],ho[],ho2[],hh[],hh2[],hl[],hl2[],hr[],hv[],hv2[],hs[];   // These arrays hold all HOURLY price information for each Symbol

int DailyBias[];
int HourlyBias[];
int HourlyTheme[];
int uphighvol[];
int dwhighvol[];
int uplowvol[];
int dwlowvol[];
double Support [][100];
double Resistance[][100];
int session; 
bool partial[];                     //Flag set if order has already been partially closed.

string ftip[];

//+------------------------------------------------------------------+
//| expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
  {
//----
   Suffix=StringSubstr(Symbol(),6,5);           // Automatically find out the Brokers Suffix
   string CRRY[112] = {"AFN","ALL","ANG","ARS","AUD","AWG","AZN","BAM","BBD","BGN","BMD","BND","BOB","BRL","BSD","BWP","BYR","BZD","CAD","CHF","CLP","CNY","COP","CRC","CUP","CZK","DKK","DOP","EEK","EGP","EUR","FJD","FKP","GBP","GGP","GHC","GIP","GTQ","GYD","HKD","HNL","HRK","HUF","IDR","ILS","IMP","INR","IRR","ISK","JEP","JMD","JPY","KGS","KHR","KPW","KYD","KZT","LAK","LBP","LKR","LRD","LTL","LVL","MKD","MNT","MUR","MXN","MYR","MZN","NAD","NGN","NIO","NOK","NPR","NZD","OMR","PAB","PEN","PHP","PKR","PLN","PYG","QAR","RON","RSD","RUB","SAR","SBD","SCR","SEK","SGD","SHP","SOS","SRD","SVC","SYP","THB","TRL","TRY","TTD","TVD","TWD","UAH","USD","UYU","UZS","VEF","VND","XCD","YER","ZAR","ZWD"};

   //--- compose list of currencies being watched ---
   string list;
   string pair;
   int pos;
   PairCount = 0;
   
   if( IsTesting() )                            // If backtesting only look at the one symbol
   {                                            
      aPair[0] = StringSubstr(Symbol(),0,6);
      PairCount = 1;
   }
   else
   {                                        // Else load all symbols from market watch into array aPair
      for (int A = 0; A != 112; A++)
      {
         for (int B = 0; B != 112; B++) 
         {
            if (A == B) continue;
            pair = CRRY[A] + CRRY[B];
            //--- check if pair is available ---
            double ask = MarketInfo(pair + Suffix, MODE_ASK);
            if (ask != 0)
            { // broker supports pair
               PairCount++;
               ArrayResize(aPair, PairCount);
               aPair[PairCount - 1] = pair;
            }
         }
      }
   }
   
   // Resize all the Arrays to number of pairs we have available
   
   ArrayResize(dc,PairCount);
   ArrayResize(dc2,PairCount);
   ArrayResize(do,PairCount);
   ArrayResize(do2,PairCount);
   ArrayResize(dh,PairCount);
   ArrayResize(dh2,PairCount);
   ArrayResize(dl,PairCount);
   ArrayResize(dl2,PairCount);
   ArrayResize(dr,PairCount);
   ArrayResize(dv,PairCount);
   ArrayResize(dv2,PairCount);
   
   ArrayResize(hc,PairCount);
   ArrayResize(hc2,PairCount);
   ArrayResize(ho,PairCount);
   ArrayResize(ho2,PairCount);
   ArrayResize(hh,PairCount);
   ArrayResize(hh2,PairCount);
   ArrayResize(hl,PairCount);
   ArrayResize(hl2,PairCount);
   ArrayResize(hv,PairCount);
   ArrayResize(hv2,PairCount);
   ArrayResize(hs,PairCount);
   ArrayResize(partial,PairCount);
   ArrayInitialize(partial,false);
   
   ArrayResize(DailyBias,PairCount);
   ArrayResize(HourlyBias,PairCount);
   ArrayResize(HourlyTheme,PairCount);
   ArrayResize(uphighvol,PairCount);
   ArrayResize(dwhighvol,PairCount);
   ArrayResize(uplowvol,PairCount);
   ArrayResize(dwlowvol,PairCount);
   ArrayResize(Support,PairCount);
   ArrayResize(Resistance,PairCount);
      
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| expert deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   if(UninitializeReason() == REASON_REMOVE)
   {
     ObjectsDelete();                     
   }
//----
   return(0);
  }

////////////////////////////////////////////////////////////////////// 
// Clear the Screen of all objects
//////////////////////////////////////////////////////////////////////                        

void ObjectsDelete()
{
   for (int i = 0;i<ArraySize(aPair);i++)
   {
      string symb = aPair[i]+Suffix;
      ObjectDelete(symb);
      ObjectDelete("Symbol"+symb);
      ObjectDelete("Symbolism"+symb);
      ObjectDelete("ResetStatus"+symb);
      ObjectDelete("CurPrice"+symb);
      ObjectDelete("DBias"+symb);
      ObjectDelete("tDBias"+symb);
      ObjectDelete("Grad1"+symb);
      ObjectDelete("Grad2"+symb);
      ObjectDelete("Grad3"+symb);
      ObjectDelete("Grad4"+symb);
      ObjectDelete("Grad5"+symb);
      ObjectDelete("Grad6"+symb);
      ObjectDelete("Txt1"+symb);
      ObjectDelete("Txt1b"+symb);
      ObjectDelete("Txt2"+symb);
      ObjectDelete("Txt2b"+symb);
      ObjectDelete("Txt3"+symb);
      ObjectDelete("Txt3b"+symb);
      ObjectDelete("Txt3c"+symb);
   }
}  
//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
{
//----
   for (int i = 0;i<=ArraySize(aPair);i++)                             
   {
      VSA_SR(aPair[i]+Suffix,i);                                     // Work through all available pairs and calculate S / R levels. Suspect this call could be moved to Order time to be more efficient.
      MetaNeural(aPair[i]+Suffix, i);                                // Main MetaNeural function.
   }
//----
   return(0);
}
//+------------------------------------------------------------------+

void MetaNeural(string symb , int index)
{
   ////////////////////////////////////////////////////////////////////
   // Resets status back to 0 on the start of a new trading session.
   // Currently this allows for only one trade per trading session. 
   // however this may be holding it back
   ////////////////////////////////////////////////////////////////////
   
   if ( (TimeHour(TimeCurrent()) == Asian_Session_Start && TimeMinute(TimeCurrent()) == 0 && TimeSeconds(TimeCurrent()) == 0 ) || (TimeHour(TimeCurrent()) == Euro_Session_Start && TimeMinute(TimeCurrent()) == 0 && TimeSeconds(TimeCurrent()) == 0 ) || (TimeHour(TimeCurrent()) == US_Session_Start && TimeMinute(TimeCurrent()) == 0 && TimeSeconds(TimeCurrent()) == 0 ) )
   {
      if(ObjectDescription("ResetStatus"+symb) == "1")
      {
         ObjectSetText("ResetStatus"+symb,"0",TextSize,"Arial");     // Resets the status back to 0 so that a new trade can be taken in the next session
         ObjectSetText("Txt2"+symb,"",TextSize,"Arial");             // Gets rid of entry criteria message.
         partial[index] = false;  
      }
   }
   
   ////////////////////////////////////////////////////////////////////
   
   //--- daily variables 
   DailyBias[index] = NONE;
   dc[index] = iClose(symb,PERIOD_D1,1);                 // previous day close
   dc2[index] = iClose(symb,PERIOD_D1,2);                // close for the day before the last day
   do[index] = iOpen(symb,PERIOD_D1,1);                  // open
   do2[index] = iOpen(symb,PERIOD_D1,2);                 // open for the day before the last day
   dh[index] = iHigh(symb,PERIOD_D1,1);                  // high
   dh2[index] = iHigh(symb,PERIOD_D1,2);                 // high for the day before the last day
   dl[index] = iLow(symb,PERIOD_D1,1);                   // low
   dl2[index] = iLow(symb,PERIOD_D1,2);                  // low for the day before the last day
   dr[index] = dh[index]-dl[index];                      // range
   dv[index] = iVolume(symb,PERIOD_D1,1);                // volume
   dv2[index] = iVolume(symb,PERIOD_D1,2);               // volume for the day before the last day
//--- daily variables

//--- hourly variables
   HourlyBias[index] = NONE;
   HourlyTheme[index] = NONE;
   ftip[index]="";
   hc[index] = iClose(symb,PERIOD_H1,1);                 // previous hour close
   hc2[index] = iClose(symb,PERIOD_H1,2);                // close for the hour before the last hour
   ho[index] = iOpen(symb,PERIOD_H1,1);                  // open
   ho2[index] = iOpen(symb,PERIOD_H1,2);                 // open for the hour before the last hour
   hh[index] = iHigh(symb,PERIOD_H1,1);                  // high
   hh2[index] = iHigh(symb,PERIOD_H1,2);                 // high for the hour before the last hour
   hl[index] = iLow(symb,PERIOD_H1,1);                   // low
   hl2[index] = iLow(symb,PERIOD_H1,2);                  // low for the hour before the last hour
   hr[index] = dh[index]-dl[index];                      // range
   hv[index] = iVolume(symb,PERIOD_H1,1);                // volume
   hv2[index] = iVolume(symb,PERIOD_H1,2);               // volume for the hour before the last hour
   hs[index] = iBarShift(symb,Period(),iTime(symb,PERIOD_H1,1),true);
   
   
   
   if(ObjectFind("CurPrice"+symb)==-1)
   {  // If Current Price is not shown then dashboard obviously has not been drawn yet.
      CreateObjects(symb , index);                                // Draw the dashboard
   }
   
   if(do[index] <= dl[index] + 0.33*dr[index] && dc[index] >= dl[index] + 0.66*dr[index] && dv[index] > dv2[index]) // clear sign of upwards strength for the previous day
   {
      DailyBias[index] = UP;
   }
   
   if(dl[index] < dl2[index] && dc[index] > do[index] && dc[index] > dl[index]+0.625*dr[index] && dv[index] > dv2[index]) // standard up bar failure
   {
      DailyBias[index] = UP;
   }
   
   if(dc[index] - do[index] <= 250*Point && dc[index] > do[index] && dv[index] > dv2[index]) // up t failure
   {
      DailyBias[index] = UP;
   }
   
   if(dl[index] < dl2[index] && dh[index] > dh2[index] && dc[index] >= dh2[index] && dv[index] > dv2[index]) // up wall failure 
   {
      DailyBias[index] = UP;
   }
   
   if(MathAbs(dc[index] - do2[index]) < 100*Point && do2[index] > dc2[index]) // reversal failure
   {
      DailyBias[index] = UP;
   }
//--- check for long bias of previous day


//--- check for short bias of previous day
   if(dc[index] <= dl[index] + 0.33*dr[index] && do[index] >= dl[index] + 0.66*dr[index] && dv[index] > dv2[index]) // clear sign of downwards strength for the previous day
   {
      DailyBias[index] = DOWN;
   }
   
   if(dh[index] > dh2[index] && dc[index] < do[index] && dc[index] < dh[index]-0.625*dr[index] && dv[index] > dv2[index]) // standard down bar failure
   {
      DailyBias[index] = DOWN;
   }
   
   if(do[index] - dc[index] <= 250*Point && dc[index] < do[index] && dv[index] > dv2[index]) // down t failure
   {
      DailyBias[index] = DOWN;
   }
   
   if(dl[index] < dl2[index] && dh[index] > dh2[index] && dc[index] <= dl2[index] && dv[index] > dv2[index]) // down wall failure 
   {
      DailyBias[index] = DOWN;
   }
   
   if(MathAbs(dc[index] - do2[index]) < 100*Point && do2[index] < dc2[index]) // reversal failure
   {
      DailyBias[index] = DOWN;
   }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////////////////
   
   uphighvol[index] = 0;
   dwhighvol[index] = 0;
   //--- check for long bias of previous hourly candle   
   if(ho[index] <= hl[index] + 0.33*hr[index] && hc[index] >= hl[index] + 0.66*hr[index] && hv[index] > hv2[index]) // clear sign of upwards strength for the previous hour
   {
      HourlyBias[index] = UP;
      HourlyTheme[index] = STRENGTH;
      uphighvol[index] = 1;
   }
   
   if(hl[index] < hl2[index] && hc[index] > ho[index] && hc[index] > hl[index]+0.625*hr[index] && hv[index] > hv2[index]) // standard up bar failure
   {
      HourlyBias[index] = UP;
      HourlyTheme[index] = FAILURE;
      ftip[index] = "Standard";
   }
   
   if(hc[index] - ho[index] <= 40*Point && hc[index] > ho[index] && hv[index] > hv2[index]) // up t failure
   {
      HourlyBias[index] = UP;
      HourlyTheme[index] = FAILURE;
      ftip[index] = "T";
   }
   
   if(hl[index] < hl2[index] && hh[index] > hh2[index] && hc[index] >= hh2[index] && hv[index] > hv2[index]) // up wall failure 
   {
      HourlyBias[index] = UP;
      HourlyTheme[index] = FAILURE;
      ftip[index] = "Wall";
   }

   if(MathAbs(hc[index] - ho2[index]) < 40*Point && ho2[index] > hc2[index]) // reversal failure
   {
      HourlyBias[index] = UP;
      HourlyTheme[index] = FAILURE;
      ftip[index] = "Reversal";
   }
//--- check for long bias of previous hourly candle

//--- check for short bias of previous hourly candle
   if(hc[index] <= hl[index] + 0.33*hr[index] && ho[index] >= hl[index] + 0.66*hr[index] && hv[index] > hv2[index]) // clear sign of downwards strength for the previous hour
   {
      HourlyBias[index] = DOWN;
      HourlyTheme[index] = STRENGTH;
      dwhighvol[index] = 1;
   }
   
   if(hh[index] > hh2[index] && hc[index] < ho[index] && hc[index] < hh[index]-0.625*hr[index] && hv[index] > hv2[index]) // standard down bar failure
   {
      HourlyBias[index] = DOWN;
      HourlyTheme[index] = FAILURE;
      ftip[index] = "Standard";
   }
   
   if(ho[index] - hc[index] <= 40*Point && hc[index] < ho[index] && hv[index] > hv2[index]) // down t failure
   {
      HourlyBias[index] = DOWN;
      HourlyTheme[index] = FAILURE;
      ftip[index] = "T";
   }
   
   if(hl[index] < hl2[index] && hh[index] > hh2[index] && hc[index] <= hl2[index] && hv[index] > hv2[index]) // down wall failure 
   {
      HourlyBias[index] = DOWN;
      HourlyTheme[index] = FAILURE;
      ftip[index] = "Wall";
   }
   
   if(MathAbs(hc[index] - ho2[index]) < 40*Point && ho2[index] < hc2[index]) // reversal failure
   {
      HourlyBias[index] = DOWN;
      HourlyTheme[index] = FAILURE;
      ftip[index] = "Reversal";
   }
//--- check for short bias of previous hourly candle

//--- long bias with lower Volume
   uplowvol[index] = 0;
   dwlowvol[index] = 0;
   
   if(ho[index] <= hl[index] + 0.33*hr[index] && hc[index] >= hl[index] + 0.66*hr[index] && hv[index] < hv2[index]) // clear sign of upwards strength for the previous hour
   {
      uplowvol[index] =1;
   }   
   
   if(hc[index] >= hl[index] + 0.66*hr[index] && ho[index] <= hl[index] + 0.5*hr[index] && ho[index] >= hl[index]+0.33*hr[index]) // sign of upward strength
   {
      if(hv[index]<hv2[index])
      uplowvol[index] = 1;
      if(hv[index]>hv2[index])
      uphighvol[index] = 1;
   }
      
   if(hl[index] < hl2[index] && hc[index] > ho[index] && hc[index] > hl[index]+0.625*hr[index] && hv[index] < hv2[index]) // standard up bar failure
   {
      uplowvol[index] = 1;
   }
   
   if(hc[index] - ho[index] <= 40*Point && hc[index] > ho[index] && hv[index] < hv2[index]) // up t failure
   {
      uplowvol[index] = 1;   
   }
   
   if(hl[index] < hl2[index] && hh[index] > hh2[index] && hc[index] >= hh2[index] && hv[index] < hv2[index]) // up wall failure 
   {
      uplowvol[index] = 1;
   }
//--- long bias with lower Volume
//--- short bias with lower Volume
   if(hc[index] <= hl[index] + 0.33*hr[index] && ho[index] >= hl[index] + 0.66*hr[index] && hv[index] < hv2[index]) // clear sign of downwards strength for the previous hour
   {
      dwlowvol[index] = 1;
   }
   
   if(hc[index] <= hl[index] + 0.33*hr[index] && ho[index] >= hl[index] + 0.5*hr[index] && ho[index] <= hl[index]+0.66*hr[index]) // sign of downward strength
   {
      if(hv[index]<hv2[index])
      dwlowvol[index] = 1;
      if(hv[index]>hv2[index])
      uphighvol[index] = 1;
   }
      
   if(hh[index] > hh2[index] && hc[index] < ho[index] && hc[index] < hh[index]-0.625*hr[index] && hv[index] < hv2[index]) // standard down bar failure
   {
      dwlowvol[index] = 1;
   }
   
   if(ho[index] - hc[index] <= 40*Point && hc[index] < ho[index] && hv[index] < hv2[index]) // down t failure
   {
      dwlowvol[index] = 1;
   }
   
   if(hl[index] < hl2[index] && hh[index] > hh2[index] && hc[index] <= hl2[index] && hv[index] < hv2[index]) // down wall failure 
   {
      dwlowvol[index] = 1;
   }
   
   Display(symb,index);    // Calls the function display. Which has control of what is displayed in the dashboard.
                           // Found this easier to split into 2 functions to help navigate around.
}
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////
// Creates all the objects in the Dashboard 
// ////////////////////////////////////////////

void CreateObjects(string symb , int yCord)
{
   string pair = symb ;
   
   ObjectCreate(pair,OBJ_LABEL,0,0,0);
   ObjectSetText(pair,symb,TextSize,"Arial",TextColor);
   ObjectSet(pair,102,10);//x value
   ObjectSet(pair,103,(TextSize+4)*yCord + 50);
   
   
   ObjectCreate("Symbolism"+symb,OBJ_LABEL,0,0,0);
   ObjectSetText("Symbolism"+symb,"6",TextSize+1,"Wingdings",TextColor);  //hourglass
   ObjectSet("Symbolism"+symb,102,75);
   ObjectSet("Symbolism"+symb,103,(TextSize+4)*yCord + 50); 
   
   ObjectCreate("ResetStatus"+symb,OBJ_LABEL,0,0,0);
   ObjectSetText("ResetStatus"+symb,"0",TextSize,"Arial",TextColor);
   ObjectSet("ResetStatus"+symb,102,95);//x value
   ObjectSet("ResetStatus"+symb,103,(TextSize+4)*yCord + 50);
 
   ObjectCreate("CurPrice"+symb,OBJ_LABEL,0,0,0);
   ObjectSet("CurPrice"+symb,102,115);//x value
   ObjectSet("CurPrice"+symb,103,(TextSize+4)*yCord + 50);//y value
   
   ObjectCreate("DBias"+symb,OBJ_LABEL,0,0,0);
   ObjectSet("DBias"+symb,102,170);//x value
   ObjectSet("DBias"+symb,103,(TextSize+4)*yCord + 50);//y value
       
   ObjectCreate("Symbol"+symb,OBJ_LABEL,0,0,0);
   ObjectSet("Symbol"+symb,102,205);//x value
   ObjectSet("Symbol"+symb,103,(TextSize+4)*yCord + 50);//y value  
   ObjectSetText("Symbol"+symb,"6",TextSize+1,"Wingdings",TextColor);  //hourglass 
     
   int GradX = 225;     // change this variable to move Gradient Bar quickly and efficiently.
   
   ObjectCreate("Grad1"+symb,OBJ_LABEL,0,0,0);
   ObjectSet("Grad1"+symb,102,GradX);//x value
   ObjectSet("Grad1"+symb,103,(TextSize+4)*yCord + 55);//y value   
   ObjectSetText("Grad1"+symb,"gg",0.5*TextSize,"Webdings");
   
   ObjectCreate("Grad2"+symb,OBJ_LABEL,0,0,0);
   ObjectSet("Grad2"+symb,102,GradX+12);//x value
   ObjectSet("Grad2"+symb,103,(TextSize+4)*yCord + 55);//y value   
   ObjectSetText("Grad2"+symb,"gg",0.5*TextSize,"Webdings");
   
   ObjectCreate("Grad3"+symb,OBJ_LABEL,0,0,0);
   ObjectSet("Grad3"+symb,102,GradX+24);//x value
   ObjectSet("Grad3"+symb,103,(TextSize+4)*yCord + 55);//y value  
   ObjectSetText("Grad3"+symb,"gg",0.5*TextSize,"Webdings");
   
   ObjectCreate("Grad4"+symb,OBJ_LABEL,0,0,0);
   ObjectSet("Grad4"+symb,102,GradX+36);//x value
   ObjectSet("Grad4"+symb,103,(TextSize+4)*yCord + 55);//y value  
   ObjectSetText("Grad4"+symb,"gg",0.5*TextSize,"Webdings");
   
   ObjectCreate("Grad5"+symb,OBJ_LABEL,0,0,0);
   ObjectSet("Grad5"+symb,102,GradX+48);//x value
   ObjectSet("Grad5"+symb,103,(TextSize+4)*yCord + 55);//y value  
   ObjectSetText("Grad5"+symb,"gg",0.5*TextSize,"Webdings");
   
   ObjectCreate("Grad6"+symb,OBJ_LABEL,0,0,0);
   ObjectSet("Grad6"+symb,102,GradX + 60);//x value
   ObjectSet("Grad6"+symb,103,(TextSize+4)*yCord + 55);//y value   
   ObjectSetText("Grad6"+symb,"gg",0.5*TextSize,"Webdings");   
   
   ObjectCreate("Txt1"+symb,OBJ_LABEL,0,0,0);
   ObjectSet("Txt1"+symb,102,305);//x value
   ObjectSet("Txt1"+symb,103,(TextSize+4)*yCord + 50);//y value      
   
   ObjectCreate("Txt2"+symb,OBJ_LABEL,0,0,0);
   ObjectSet("Txt2"+symb,102,605);//x value
   ObjectSet("Txt2"+symb,103,(TextSize+4)*yCord + 50);//y value

   ObjectCreate("Txt3"+symb,OBJ_LABEL,0,0,0);
   ObjectSet("Txt3"+symb,102,840);//x value
   ObjectSet("Txt3"+symb,103,(TextSize+4)*yCord + 50);//y value 
   ObjectSetText("Txt3"+symb,"");
   
   Comment("MetaNeural Dashboard", "\n",
           "Developed by: MetaNeural Trading", "\n");

}
///////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////
// Display function controls what is displayed in the dashboard.
// Also contains trade functions
///////////////////////////////////////////////////////////////////////////////////////////
void Display(string symb ,int index)
{
   double c = iClose(symb,0,0);
   int d = MarketInfo(symb,MODE_DIGITS);
   double TP = 0;
   double STOP = 0;
   
   ObjectSetText("CurPrice"+symb,DoubleToStr(c,d),TextSize,"Arial",TextColor);   
   ObjectSetText("DBias"+symb,"gg",TextSize,"Webdings");           // Set all Direction Bias Box to a box.
   ObjectSetText("tDBias"+symb,"D1",TextSize,"Arial",TextColor);   // D1 text below
   
   /// setting box color
   /////////////////////////////////////////
   if(DailyBias[index] == UP)                                      //
   ObjectSet("DBias"+symb,6,Lime);                                 // If Up make it green
   else if(DailyBias[index] == DOWN)                               //  
   ObjectSet("DBias"+symb,6,Red);                                  // If Down Make it Red
   else ObjectSet("DBias"+symb,6,TextColor);                       // If Neither make it white.
    
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////

   if(DailyBias[index] == DOWN && HourlyTheme[index] == FAILURE && HourlyBias[index] == DOWN && ObjectDescription("Symbolism"+symb) == "6")
   {
      ObjectSetText("Symbol"+symb,"",TextSize,"Wingdings");      //down arrow
      ObjectSetText("Symbolism"+symb,"",TextSize,"Wingdings");   //down arrow
      ObjectSet("Symbol"+symb,6,Red);
      UpdateGradient(symb,1);
   }
   
   if(DailyBias[index] == UP && HourlyTheme[index] == FAILURE && HourlyBias[index] == UP  && ObjectDescription("Symbolism"+symb) == "6")
   {
      ObjectSetText("Symbol"+symb,"",TextSize,"Wingdings");      //up arrow
      ObjectSetText("Symbolism"+symb,"",TextSize,"Wingdings");   //up arrow   
      ObjectSet("Symbol"+symb,6,Lime);
      UpdateGradient(symb,2);
   }
   
///////////////////////////////////////////////////////////////////////////////////////////
   
   if(ObjectDescription("Symbolism"+symb) == "") // we are in a long trade
   {
      if(dwlowvol[index] == 1)
      {
         ObjectSetText("Txt3"+symb,"Weak DOWN move, smart money not interested, Stay In",TextSize,"Arial",TextColor);
         ObjectSetText("Symbol"+symb,"",TextSize,"Wingdings",Lime);   //up
         UpdateGradient(symb,4);
      }
      
      else if(dwhighvol[index] == 1)
      {
         ObjectSetText("Txt3"+symb,"Strength coming in to the DOWNSIDE Trade is still valid, Stay In",TextSize,"Arial",TextColor);      
         ObjectSetText("Symbol"+symb,"",TextSize,"Wingdings",Lime);   //up
         UpdateGradient(symb,4);      
      }
      
      else if(HourlyBias[index] == DOWN && dwhighvol[index] == 0)
      {
         ObjectSetText("Txt3"+symb,"Direction change imminent, consider taking partial profit, keep partial order in until TP",TextSize,"Arial",TextColor);
         ObjectSetText("Symbol"+symb,"r",TextSize,"Webdings",TextColor);  //X
         UpdateGradient(symb,5);
         if (partial[index] == false)
         {
            PartialClose(symb);
            partial[index] = true;
         }
          
      }
      
      else if(HourlyBias[index] == UP || uphighvol[index] == 1 || uplowvol[index] == 1)
      {      
         ObjectSetText("Txt3"+symb,"Trade direction is confirmed and still valid, STAY IN until TP",TextSize,"Arial",TextColor);
         ObjectSetText("Symbol"+symb,"",TextSize,"Wingdings",Lime);   //up
         UpdateGradient(symb,2);     
      }
      
      else
      {
         ObjectSetText("Symbol"+symb,"6",TextSize,"Wingdings",TextColor);  //hourglass   
         ObjectSetText("Txt3"+symb,"NEUTRAL - Waiting for next signal",TextSize,"Arial",TextColor);
         CloseIfInProfit(symb,index);
         UpdateGradient(symb,0);
      }
   }

///////////////////////////////////////////////////////////////////////////////////////////////////////////////

if(ObjectDescription("Symbolism"+symb) == "") // we are in a short trade
   {   
      if(uplowvol[index] == 1)
      {
         ObjectSetText("Txt3"+symb,"Weak UP move, smart money not interested, Stay In",TextSize,"Arial",TextColor);
         ObjectSetText("Symbol"+symb,"",TextSize,"Wingdings",Red);   //down     
      }
      
      else if(dwhighvol[index] == 1)
      {
         ObjectSetText("Txt3"+symb,"Strength coming in to the UPSIDE Trade is still valid, Stay In",TextSize,"Arial",TextColor);
         ObjectSetText("Symbol"+symb,"",TextSize,"Wingdings",Red);   //down    
      }     
      
      else if(HourlyBias[index] == UP && uphighvol[index] == 0)
      {
         ObjectSetText("Txt3"+symb,"Direction change imminent, consider taking partial profit, keep partial order in until TP",TextSize,"Arial",TextColor);
         ObjectSetText("Symbol"+symb,"r",TextSize,"Webdings",TextColor);  //X
         if (partial[index] == false)
         {
            PartialClose(symb);
            partial[index] = true;
         }   
      }
      
      else if(HourlyBias[index] == DOWN || dwhighvol[index] == 1 || dwlowvol[index] == 1)
      {      
         ObjectSetText("Txt3"+symb,"Trade direction is confirmed and still valid, STAY IN until TP",TextSize,"Arial",TextColor);
         ObjectSetText("Symbol"+symb,"",TextSize,"Wingdings",Red);   //down      
      }      
      
      else
      {
         ObjectSetText("Symbol"+symb,"6",TextSize,"Wingdings",TextColor);  //hourglass   
         ObjectSetText("Txt3"+symb,"NEUTRAL - Waiting for next signal",TextSize,"Arial",TextColor);
         CloseIfInProfit(symb,index);
      }
             
   }
   
   //////////////////////////////////////////////////////////////////////////////////////////////////////////
   
   if(DailyBias[index] == UP && ObjectDescription("Symbolism"+symb) == "6")
   {     
		ObjectSetText("Txt1"+symb,"Directional Bias for today is UP",TextSize,"Arial",TextColor);
   }
   else if(DailyBias[index] == DOWN && ObjectDescription("Symbolism"+symb) == "6")
   {   
		ObjectSetText("Txt1"+symb,"Directional Bias for today is DOWN",TextSize,"Arial",TextColor);
   }
   else if(ObjectDescription("Symbolism"+symb) == "6") 
   {  
		ObjectSetText("Txt1"+symb,"There is no directional bias for today",TextSize,"Arial",TextColor);
   }
   else if(DailyBias[index] == UP && ObjectDescription("Symbolism"+symb) == "" && ObjectDescription("Symbol"+symb) == "")
   {
		ObjectSetText("Txt1"+symb,"A "+ ftip[index] + " failure has occured " + " on "+ symb + " H1 " + "at " + DoubleToStr(TimeHour(Time[1]),0) + ":" + "00",TextSize,"Arial",TextColor);
	}
   else if(DailyBias[index] == DOWN && ObjectDescription("Symbolism"+symb) == "" && ObjectDescription("Symbol"+symb) == "")
   {
		ObjectSetText("Txt1"+symb,"A "+ ftip[index] + " failure has occured on "+ symb + " H1 " + "at " + DoubleToStr(TimeHour(Time[1]),0) + ":" + "00",TextSize,"Arial",TextColor);
	} 
   
/////////////////////////////////////////////////////////////////////////////////////////////

//update second text command
   if(DailyBias[index] == UP && ObjectDescription("Symbolism"+symb) == "6")
   {   
		ObjectSetText("Txt2"+symb,"Waiting for a failure of the downside",TextSize,"Arial",TextColor); 
	}
   else if(DailyBias[index] == DOWN && ObjectDescription("Symbolism"+symb) == "6")
   {
		ObjectSetText("Txt2"+symb,"Waiting for a failure of the upside",TextSize,"Arial",TextColor);    
   }
   else if(ObjectDescription("Symbolism"+symb) == "6") 
   {
		ObjectSetText("Txt2"+symb,"",TextSize,"Arial",TextColor);
   }
   else if(ObjectDescription("Symbolism"+symb) == "" && ObjectDescription("Symbol"+symb) == "")
   {
      TP = FindTP(index,hc[index],UP);
      STOP = FindTP(index,hc[index],DOWN);
           
		ObjectSetText("Txt2"+symb,"Open BUY at " + DoubleToStr(hc[index],d) + "  TP at " + DoubleToStr(TP,d),TextSize,"Arial",TextColor);
		if(TradeEnabled)
		{
		    if (ObjectDescription("ResetStatus"+symb) == "0")
		    {
            if (( MathAbs(hc[index] - STOP) / MarketInfo(symb,MODE_POINT) ) < 150)        //
            {                                                           //
               STOP = (hc[index] - (150 * MarketInfo(symb,MODE_POINT) ) );                  //
            }
                                                                        //
            LotSize = Lot(symb,hc[index],STOP,"BUY");                   //
            
            if( c < hc[index] )                                         // If the current price is less than entry price use BUYSTOP
            {
		          if( OrderSend(symb,OP_BUYSTOP,LotSize,hc[index],100,0,0,TradeComment,MAGIC,0,Green) != -1 )
		          {
		             SetStopAndTP(symb,STOP,TP);                                                               // Set Stop after order for ECN compatibilty
		             ObjectSetText("ResetStatus"+symb,"1",TextSize,"Arial");
		          }                                                                                            // Set the Status to say an order has been placed in this current session
		      }
		      else if ( c > hc[index] )                                   // If the current price is higher than entry use BUYLIMIT
		      {
		          if( OrderSend(symb,OP_BUYLIMIT,LotSize,hc[index],100,0,0,TradeComment,MAGIC,0,Green) != -1 )
		          {
		             SetStopAndTP(symb,STOP,TP);                                                               // Set Stop after order for ECN compatibilty
		             ObjectSetText("ResetStatus"+symb,"1",TextSize,"Arial");
		          }
		      }                                                                                             // If we can set a BUYSTOP or BUYLIMIT entry price must be too close to current price. So just use an ordinary buy order.
		      else if ( OrderSend(symb,OP_BUY,LotSize,hc[index],100,0,0,TradeComment,MAGIC,0,Green) != -1 ) // This is an attempt to place te order if the open price is too close to 
		      {                                                                                             // the current price.(Could be better)
		          SetStopAndTP(symb,STOP,TP);                                                               // Set Stop after order for ECN compatibilty
		          ObjectSetText("ResetStatus"+symb,"1",TextSize,"Arial");                                   // Set the Status to say an order has been placed in this current session
		      }
		   } 
		}  
   }
   else if(ObjectDescription("Symbolism"+symb) == "" && ObjectDescription("Symbol"+symb) == "")
   {
      TP = FindTP(index,hc[index],DOWN);
      STOP = FindTP(index,hc[index],UP);
            
		ObjectSetText("Txt2"+symb,"Open SELL at " + DoubleToStr(hc[index],d)+ "  TP at " + DoubleToStr(TP,d),TextSize,"Arial",TextColor);
		if(TradeEnabled)
		{
		    if (ObjectDescription("ResetStatus"+symb) == "0")
		    {
            if ( (MathAbs( STOP - hc[index] ) / MarketInfo(symb,MODE_POINT) ) < 150)           
            {                                                           //
               STOP = ( hc[index] + (150 * MarketInfo(symb,MODE_POINT) ) );                  // If the Stop is less than 15 Pips away from open price.
            }                                                                                // Bear in mind that stop distance is inversely linked to lotsize so that you only lose a ceratin % if Stop is hit.
                                                                                             // If you increase the minimum stop size you may well reduce the lotsize & therfore any potential gain.
            LotSize = Lot(symb,hc[index],STOP,"SELL"); 
            if( c > hc[index] )                                                              // If the current price is higher than entry price use SELL STOP
            {
		          if( OrderSend(symb,OP_SELLSTOP,LotSize,hc[index],100,0,0,TradeComment,MAGIC,0,Green) != -1)
		          {
		             SetStopAndTP(symb,STOP,TP);                                                                  // Set Stop after order for ECN compatibilty
		             ObjectSetText("ResetStatus"+symb,"1",TextSize,"Arial");                                      // Set the Status to say an order has been placed in this current session
		          }
		      }
		      else if ( c < hc[index] )                                   // If the current price is higher than entry use SELL LIMIT
		      {
		          if( OrderSend(symb,OP_SELLLIMIT,LotSize,hc[index],100,0,0,TradeComment,MAGIC,0,Green) != -1)
		          {
		             SetStopAndTP(symb,STOP,TP);                                                                  // Set Stop after order for ECN compatibilty
		             ObjectSetText("ResetStatus"+symb,"1",TextSize,"Arial");                                      // Set the Status to say an order has been placed in this current session
		          } 
		      }
		      else if ( OrderSend(symb,OP_SELL,LotSize,hc[index],100,0,0,TradeComment,MAGIC,0,Green) != -1 )   // This is an attempt to place the order if the open price is too close to 
		      {                                                                                                // the current price.(Could be better)!!
		          SetStopAndTP(symb,STOP,TP);                                                                  // Set Stop after order for ECN compatibilty
		          ObjectSetText("ResetStatus"+symb,"1",TextSize,"Arial");                                      // Set the Status to say an order has been placed in this current session
		      }
		   }
		}
   }     
}

///////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////
// Change the color of the Gradiant to give some kind of visual indication of 
// strength and direction.
///////////////////////////////////////////////////////////////////////////////////////
void UpdateGradient(string symb , int type)
{
   if(type==0) // neutral
   {
   ObjectSet("Grad1"+symb,6,Lime);
   ObjectSet("Grad2"+symb,6,LawnGreen);
   ObjectSet("Grad3"+symb,6,YellowGreen);   
   ObjectSet("Grad4"+symb,6,DarkOrange);
   ObjectSet("Grad5"+symb,6,OrangeRed);
   ObjectSet("Grad6"+symb,6,Red);
   }

   if(type==1) // one color - red
   {   
   ObjectSet("Grad1"+symb,6,Red);
   ObjectSet("Grad2"+symb,6,Red);
   ObjectSet("Grad3"+symb,6,Red);   
   ObjectSet("Grad4"+symb,6,Red);
   ObjectSet("Grad5"+symb,6,Red);
   ObjectSet("Grad6"+symb,6,Red);   
   }
   
   if(type==2) // one color - green
   {   
   ObjectSet("Grad1"+symb,6,Lime);
   ObjectSet("Grad2"+symb,6,Lime);
   ObjectSet("Grad3"+symb,6,Lime);   
   ObjectSet("Grad4"+symb,6,Lime);
   ObjectSet("Grad5"+symb,6,Lime);
   ObjectSet("Grad6"+symb,6,Lime);
   }
   
   if(type==4) // medium 
   {   
   ObjectSet("Grad1"+symb,6,Lime);
   ObjectSet("Grad2"+symb,6,Lime);
   ObjectSet("Grad3"+symb,6,Lime);   
   ObjectSet("Grad4"+symb,6,Red);
   ObjectSet("Grad5"+symb,6,Red);
   ObjectSet("Grad6"+symb,6,Red);
   }

   if(type==5) // least - red
   {   
   ObjectSet("Grad1"+symb,6,Lime);
   ObjectSet("Grad2"+symb,6,Lime);
   ObjectSet("Grad3"+symb,6,OrangeRed);   
   ObjectSet("Grad4"+symb,6,Red);
   ObjectSet("Grad5"+symb,6,Red);
   ObjectSet("Grad6"+symb,6,Red);  
   }
      
   if(type==6) // least - green
   {   
   ObjectSet("Grad1"+symb,6,Lime);
   ObjectSet("Grad2"+symb,6,Lime);
   ObjectSet("Grad3"+symb,6,Lime);   
   ObjectSet("Grad4"+symb,6,Lime);
   ObjectSet("Grad5"+symb,6,OrangeRed);
   ObjectSet("Grad6"+symb,6,Red);
   }
}
//////////////////////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////////////////////
// Attempt at the combination of VSA_SR indicator and the dashboard
// Calculates support and resistance lines to be used as SL and TP
//////////////////////////////////////////////////////////////////////////////////////////////////

void VSA_SR(string symb, int index)
{
   int    counted_bars=IndicatorCounted();
//----

   int x = 0;
   ArrayResize(Support,BarsBack);
   ArrayResize(Resistance,BarsBack);
   ArrayInitialize(Support,0);
   ArrayInitialize(Resistance,0);
   
   for(int i=BarsBack;i>0;i--)
   {
      if(Period() == PERIOD_H1)
      {
         if( ((iClose(symb,PERIOD_H1,i) > iOpen(symb,PERIOD_H1,i) && iClose(symb,PERIOD_H1,i) > (iHigh(symb,PERIOD_H1,i)+iLow(symb,PERIOD_H1,i))/2) ||  (iClose(symb,PERIOD_H1,i) > (iHigh(symb,PERIOD_H1,i)+iLow(symb,PERIOD_H1,i))/2 && iClose(symb,PERIOD_H1,i) == iOpen(symb,PERIOD_H1,i))) && iVolume(symb,Period(),i)>iVolume(symb,Period(),i+1))
         { // if it is an up bar that shows buying strength
            Support[index][i] = iClose(symb,PERIOD_H1,i);
            for(int k = BarsBack; k>i; k--)
            {
               if(Resistance[index][k] <= iClose(symb,PERIOD_H1,i))
               {
                  Resistance[index][k] = 0;
               }     
            }
         }
         if( ((iClose(symb,PERIOD_H1,i) < iOpen(symb,PERIOD_H1,i) && iClose(symb,PERIOD_H1,i) > (iHigh(symb,PERIOD_H1,i)+iLow(symb,PERIOD_H1,i))/2) ||  (iClose(symb,PERIOD_H1,i) < (iHigh(symb,PERIOD_H1,i)+iLow(symb,PERIOD_H1,i))/2 && iClose(symb,PERIOD_H1,i) == iOpen(symb,PERIOD_H1,i))) && iVolume(symb,Period(),i)>iVolume(symb,Period(),i+1))       
         {
            Support[index][i] = iClose(symb,PERIOD_H1,i);
            for(int sktt = BarsBack; sktt>i; sktt--)
            {
               if(Support[index][sktt] >= iClose(symb,PERIOD_H1,i))
               {
                  Support[index][sktt] = 0;
               }     
            }
         }
         if( ((iClose(symb,PERIOD_H1,i) < iOpen(symb,PERIOD_H1,i) && iClose(symb,PERIOD_H1,i) < (iHigh(symb,PERIOD_H1,i)+iLow(symb,PERIOD_H1,i))/2) ||  (iClose(symb,PERIOD_H1,i) < (iHigh(symb,PERIOD_H1,i)+iLow(symb,PERIOD_H1,i))/2 && iClose(symb,PERIOD_H1,i) == iOpen(symb,PERIOD_H1,i))) && iVolume(symb,Period(),i)>iVolume(symb,Period(),i+1))      
         {
            Resistance[index][i] = iClose(symb,PERIOD_H1,i);
            for(int ktt = BarsBack; ktt>i; ktt--)
            {
               if(Support[index][ktt] >= iClose(symb,PERIOD_H1,i))
               {
                  Support[index][ktt] = 0;
               } 
            } 
         }
         if( ((iClose(symb,PERIOD_H1,i) > iOpen(symb,PERIOD_H1,i) && iClose(symb,PERIOD_H1,i) < (iHigh(symb,PERIOD_H1,i)+iLow(symb,PERIOD_H1,i))/2) ||  (iClose(symb,PERIOD_H1,i) < (iHigh(symb,PERIOD_H1,i)+iLow(symb,PERIOD_H1,i))/2 && iClose(symb,PERIOD_H1,i) == iOpen(symb,PERIOD_H1,i))) && iVolume(symb,Period(),i)>iVolume(symb,Period(),i+1))
         {
            Resistance[index][i] = iClose(symb,PERIOD_H1,i);
            for(int kt = BarsBack; kt>i; kt--)
            {
               if(Resistance[index][kt] <= iClose(symb,PERIOD_H1,i))
               {
                  Resistance[index][kt] = 0;
               }      
            }
         }
      }
   }
   
   /////////////////////////////////////////////////////////////////////////////////////
   // A Test to display S / R levels
   // 
   /*

   for (int v=0 ; v <= ArraySize(Support) ; v++)
   {
      if(Support[index][v] != 0)
      {
         ObjectCreate("Green"+DoubleToStr(v,0),OBJ_HLINE,0,Time[v],Support[index][v]);
         ObjectSet("Green"+DoubleToStr(v,0),6,Chartreuse);     
         ObjectSet("Green"+DoubleToStr(v,0),7,STYLE_DASH);
         Alert(symb,Support[index][v]);
      }
   }
   for (int j=0 ; j <= ArraySize(Resistance) ; j++)
   {
      if(Resistance[index][j] != 0)
      {
         ObjectCreate("Red"+DoubleToStr(j,0),OBJ_HLINE,0,Time[j],Resistance[index][j]);
         ObjectSet("Red"+DoubleToStr(j,0),6,Red);     
         ObjectSet("Red"+DoubleToStr(j,0),7,STYLE_DASH);
         Alert(symb,Resistance[index][j]);
      }
   }
   */ 
  
   
   //////////////////////////////////////////////////////////////////////////////////////
   return(0);
}

/////////////////////////////////////////////////////////////////////////////////////////
// Function finds the nearest Support or Resistance line to be used for SL and TP
/////////////////////////////////////////////////////////////////////////////////////////
double FindTP(int index, double entry, int direction)
{
   double tp,min;
   if(direction == UP)
   {
      min = 10000;
      for(int i = BarsBack ;i>=0;i--)
      {
         if(Resistance[index][i] > entry+150*Point && Resistance[index][i] < min)
         {
            min = Resistance[index][i];
         }        
      }
      if (min == 10000)
      {
         min = entry+150*Point;
      }
   }
   if(direction == DOWN)
   {
      min = 0;
      for(int ii = BarsBack;ii>=0;ii--)
      {
         if(Support[index][ii] < entry-150*Point && Support[index][ii] > min)
         {
            min = Support[index][ii];
         }        
      }
      if (min == 0)
      {
         min = entry-150*Point;
      }
   }
   
   return(min);  
}

double Lot(string symb , double Entry , double StopLoss , string Direction)
{
   double lot;
   double range;
   double AmountToRisk;
   int symbdigits = MarketInfo(symb,MODE_DIGITS);
   double NumberOfPips;
   if (Risk > 0.0)
   {     
      if (Direction == "BUY")                                                 // TBH I dont know why I did this
      {                                                                       // It actually looks useless
         range = MathAbs(Entry - StopLoss);                                   // Havnt deleted it yet because its linked to other stuff
      }                                                                       // and want to start trading.
      if (Direction == "SELL")
      {
         range = MathAbs(Entry - StopLoss);
      }
   // Take Risk% of our account size and divide it by range.
   
      AmountToRisk = AccountEquity() / 100 * Risk;                            // Amount to risk on the trade as a percentage of equity
      NumberOfPips = ( range / MarketInfo(symb,MODE_POINT) );                                    // The number of POINTS between open price and SL
      lot = AmountToRisk / NumberOfPips;                                      // How much is each point worth. If SL is hit only % of equity is lost.
      if(lot<MarketInfo(symb,MODE_MINLOT)) lot=MarketInfo(symb,MODE_MINLOT);  // If lotsize is less than minimum allowed make it = the minimum
      
      //Alert(symb + " Amount To Risk = " + DoubleToStr(AmountToRisk,2) + " Number of Pips = " + DoubleToStr(NumberOfPips,0) + "  Lot Size = " + DoubleToStr(lot,2)); 
      return(lot);
   }
   else 
   {
      return(LotSize);
   }
}

/*
int CurrentSession()
{
   if(TimeHour(TimeCurrent()) >= Asian_Session_Start && TimeHour(TimeCurrent()) < Euro_Session_Start)
      return(1);
   if(TimeHour(TimeCurrent()) >= Euro_Session_Start && TimeHour(TimeCurrent()) < US_Session_Start)
      return(2);
   if(TimeHour(TimeCurrent()) >= US_Session_Start && TimeHour(TimeCurrent()) < 24)
      return(3);
}
*/

/////////////////////////////////////////////////
// Close the order but only if it is in profit //
/////////////////////////////////////////////////

void CloseIfInProfit(string symb , int index)
{
   for (int i = 0;i <= OrdersTotal();i++)
   {
       if( OrderSelect(i,SELECT_BY_POS,MODE_TRADES) )
       {
          if( OrderSymbol() == symb ) 
          {
            double profit = ( OrderProfit() - OrderCommission () - OrderSwap() );
            if( ( OrderType() == OP_BUY || OrderType() == OP_SELL) && ( profit >= 0 ) && (OrderMagicNumber() == MAGIC) )
            {
               OrderClose(OrderTicket(),OrderLots(),MarketInfo(symb,MODE_BID),100,Red);   // Close any open orders
               ObjectSetText("Txt2"+symb,"",TextSize,"Arial");                            // Gets rid of entry criteria message.    
            }
            if (OrderType() == OP_BUYSTOP || OrderType() == OP_SELLSTOP)
            {
               OrderDelete(OrderTicket());                                                // Delete any pending orders
               ObjectSetText("Txt2"+symb,"",TextSize,"Arial");                            // Gets rid of entry criteria message. 
            }
          }
       }
   }
   partial[index] = false;
}

//////////////////////////////////////////////////////////////////
// Partial Close the order by a certain % but only if in profit //
//////////////////////////////////////////////////////////////////

void PartialClose(string symb)
{
   for (int i = 0;i <= OrdersTotal();i++)
   {
       if( OrderSelect(i,SELECT_BY_POS,MODE_TRADES) )
       {
          if( OrderSymbol() == symb && OrderMagicNumber() == MAGIC) 
          {
            double profit = ( OrderProfit() - OrderCommission () - OrderSwap() );
            if( (OrderType() == OP_BUY || OrderType() == OP_SELL) && profit >= 0 )
            {
               double partiallotsize = NormalizeDouble( (OrderLots()/100)*PartialTakePercentage , 2) ;  // Calculate % of total lotsize to close
               OrderClose(OrderTicket(),partiallotsize,MarketInfo(symb,MODE_BID),100,Red);              // Close % of open order 
               ObjectSetText("Txt2"+symb,"",TextSize,"Arial");                                          // Gets rid of entry criteria message.    
            }
            if (OrderType() == OP_BUYSTOP || OrderType() == OP_SELLSTOP)
            {
               OrderDelete(OrderTicket());                                                              // Close the order if it never opened. Probably not needed 
               ObjectSetText("Txt2"+symb,"",TextSize,"Arial");                                          // Gets rid of entry criteria message. 
            }
          }
       }
   }   
}

///////////////////////////////////////////////////////////////
// Used to set STOP and TP on an open order.                 //
// Gives us compatibility with ECN                           //
///////////////////////////////////////////////////////////////

void SetStopAndTP(string symb , double STOP , double TP)
{
   for (int i = 0;i <= OrdersTotal();i++)
   {
      if( OrderSelect(i,SELECT_BY_POS,MODE_TRADES) )
      {
         if( OrderSymbol() == symb && OrderMagicNumber() == MAGIC) 
         {
            // Alert("ORDER " + OrderTicket() + " " + symb + " STOP = " + STOP + " TP = " + TP );   // Alert if you need to check STOP and TP distances
            OrderModify(OrderTicket(),OrderOpenPrice(),STOP,TP,0,0);
         }
      }
   }
}

